From 2dfeb34944e4b167d36df3125ab8cfbe4e3550e3 Mon Sep 17 00:00:00 2001
From: Daniel Gustafsson <dgustafsson@postgresql.org>
Date: Tue, 3 May 2022 14:09:02 +0200
Subject: [PATCH] Rename libpq test programs with libpq_ prefix

The testclient and uri-regress programs in the libpq test suite had
quite generic names which didn't convey much meaning. Since they are
installed as part of the MSVC test runs, ensure that their purpose
is a little bit clearer by renaming with a libpq_ prefix.

Reported-by: Noah Misch <noah@leadboat.com>
Discussion: https://postgr.es/m/20220501080706.GA1542365@rfd.leadboat.com
---
 src/interfaces/libpq/t/001_uri.pl             | 30 +++++++++----------
 src/interfaces/libpq/t/002_api.pl             |  2 +-
 src/interfaces/libpq/test/.gitignore          |  4 +--
 src/interfaces/libpq/test/Makefile            |  2 +-
 .../test/{testclient.c => libpq_testclient.c} |  4 +--
 .../{uri-regress.c => libpq_uri-regress.c}    |  8 ++---
 src/tools/msvc/Mkvcbuild.pm                   |  8 ++---
 7 files changed, 29 insertions(+), 29 deletions(-)
 rename src/interfaces/libpq/test/{testclient.c => libpq_testclient.c} (88%)
 rename src/interfaces/libpq/test/{uri-regress.c => libpq_uri-regress.c} (90%)

diff --git a/src/interfaces/libpq/t/001_uri.pl b/src/interfaces/libpq/t/001_uri.pl
index 1d595c0529..a50ae001cb 100644
--- a/src/interfaces/libpq/t/001_uri.pl
+++ b/src/interfaces/libpq/t/001_uri.pl
@@ -72,7 +72,7 @@ my @tests = (
 	],
 	[
 		q{postgresql://host/db?u%7aer=someotheruser&port=12345}, q{},
-		q{uri-regress: invalid URI query parameter: "uzer"},
+		q{libpq_uri-regress: invalid URI query parameter: "uzer"},
 	],
 	[
 		q{postgresql://host:12345?user=uri-user},
@@ -114,63 +114,63 @@ my @tests = (
 	],
 	[
 		q{postgresql://host?uzer=}, q{},
-		q{uri-regress: invalid URI query parameter: "uzer"},
+		q{libpq_uri-regress: invalid URI query parameter: "uzer"},
 	],
 	[
 		q{postgre://},
 		q{},
-		q{uri-regress: missing "=" after "postgre://" in connection info string},
+		q{libpq_uri-regress: missing "=" after "postgre://" in connection info string},
 	],
 	[
 		q{postgres://[::1},
 		q{},
-		q{uri-regress: end of string reached when looking for matching "]" in IPv6 host address in URI: "postgres://[::1"},
+		q{libpq_uri-regress: end of string reached when looking for matching "]" in IPv6 host address in URI: "postgres://[::1"},
 	],
 	[
 		q{postgres://[]},
 		q{},
-		q{uri-regress: IPv6 host address may not be empty in URI: "postgres://[]"},
+		q{libpq_uri-regress: IPv6 host address may not be empty in URI: "postgres://[]"},
 	],
 	[
 		q{postgres://[::1]z},
 		q{},
-		q{uri-regress: unexpected character "z" at position 17 in URI (expected ":" or "/"): "postgres://[::1]z"},
+		q{libpq_uri-regress: unexpected character "z" at position 17 in URI (expected ":" or "/"): "postgres://[::1]z"},
 	],
 	[
 		q{postgresql://host?zzz},
 		q{},
-		q{uri-regress: missing key/value separator "=" in URI query parameter: "zzz"},
+		q{libpq_uri-regress: missing key/value separator "=" in URI query parameter: "zzz"},
 	],
 	[
 		q{postgresql://host?value1&value2},
 		q{},
-		q{uri-regress: missing key/value separator "=" in URI query parameter: "value1"},
+		q{libpq_uri-regress: missing key/value separator "=" in URI query parameter: "value1"},
 	],
 	[
 		q{postgresql://host?key=key=value},
 		q{},
-		q{uri-regress: extra key/value separator "=" in URI query parameter: "key"},
+		q{libpq_uri-regress: extra key/value separator "=" in URI query parameter: "key"},
 	],
 	[
 		q{postgres://host?dbname=%XXfoo}, q{},
-		q{uri-regress: invalid percent-encoded token: "%XXfoo"},
+		q{libpq_uri-regress: invalid percent-encoded token: "%XXfoo"},
 	],
 	[
 		q{postgresql://a%00b},
 		q{},
-		q{uri-regress: forbidden value %00 in percent-encoded value: "a%00b"},
+		q{libpq_uri-regress: forbidden value %00 in percent-encoded value: "a%00b"},
 	],
 	[
 		q{postgresql://%zz}, q{},
-		q{uri-regress: invalid percent-encoded token: "%zz"},
+		q{libpq_uri-regress: invalid percent-encoded token: "%zz"},
 	],
 	[
 		q{postgresql://%1}, q{},
-		q{uri-regress: invalid percent-encoded token: "%1"},
+		q{libpq_uri-regress: invalid percent-encoded token: "%1"},
 	],
 	[
 		q{postgresql://%}, q{},
-		q{uri-regress: invalid percent-encoded token: "%"},
+		q{libpq_uri-regress: invalid percent-encoded token: "%"},
 	],
 	[ q{postgres://@host},   q{host='host' (inet)},   q{}, ],
 	[ q{postgres://host:/},  q{host='host' (inet)},   q{}, ],
@@ -224,7 +224,7 @@ sub test_uri
 
 	$expect{'exit'} = $expect{stderr} eq '';
 
-	my $cmd = [ 'uri-regress', $uri ];
+	my $cmd = [ 'libpq_uri-regress', $uri ];
 	$result{exit} = IPC::Run::run $cmd, '>', \$result{stdout}, '2>',
 	  \$result{stderr};
 
diff --git a/src/interfaces/libpq/t/002_api.pl b/src/interfaces/libpq/t/002_api.pl
index 7c6c5788a0..8b3355e6dd 100644
--- a/src/interfaces/libpq/t/002_api.pl
+++ b/src/interfaces/libpq/t/002_api.pl
@@ -6,7 +6,7 @@ use PostgreSQL::Test::Utils;
 use Test::More;
 
 # Test PQsslAttribute(NULL, "library")
-my ($out, $err) = run_command(['testclient', '--ssl']);
+my ($out, $err) = run_command(['libpq_testclient', '--ssl']);
 
 if ($ENV{with_ssl} eq 'openssl')
 {
diff --git a/src/interfaces/libpq/test/.gitignore b/src/interfaces/libpq/test/.gitignore
index 4b17210483..bbc7372e29 100644
--- a/src/interfaces/libpq/test/.gitignore
+++ b/src/interfaces/libpq/test/.gitignore
@@ -1,2 +1,2 @@
-/testclient
-/uri-regress
+/libpq_testclient
+/libpq_uri-regress
diff --git a/src/interfaces/libpq/test/Makefile b/src/interfaces/libpq/test/Makefile
index 1d45be0c37..a88db0e86a 100644
--- a/src/interfaces/libpq/test/Makefile
+++ b/src/interfaces/libpq/test/Makefile
@@ -11,7 +11,7 @@ endif
 override CPPFLAGS := -I$(libpq_srcdir) $(CPPFLAGS)
 LDFLAGS_INTERNAL += $(libpq_pgport)
 
-PROGS = testclient uri-regress
+PROGS = libpq_testclient libpq_uri-regress
 
 all: $(PROGS)
 
diff --git a/src/interfaces/libpq/test/testclient.c b/src/interfaces/libpq/test/libpq_testclient.c
similarity index 88%
rename from src/interfaces/libpq/test/testclient.c
rename to src/interfaces/libpq/test/libpq_testclient.c
index 2c730d83fa..d945bacf1b 100644
--- a/src/interfaces/libpq/test/testclient.c
+++ b/src/interfaces/libpq/test/libpq_testclient.c
@@ -1,11 +1,11 @@
 /*
- * testclient.c
+ * libpq_testclient.c
  *		A test program for the libpq public API
  *
  * Copyright (c) 2022, PostgreSQL Global Development Group
  *
  * IDENTIFICATION
- *		src/interfaces/libpq/test/testclient.c
+ *		src/interfaces/libpq/test/libpq_testclient.c
  */
 
 #include "postgres_fe.h"
diff --git a/src/interfaces/libpq/test/uri-regress.c b/src/interfaces/libpq/test/libpq_uri-regress.c
similarity index 90%
rename from src/interfaces/libpq/test/uri-regress.c
rename to src/interfaces/libpq/test/libpq_uri-regress.c
index c5ef33c46b..3c0561ab12 100644
--- a/src/interfaces/libpq/test/uri-regress.c
+++ b/src/interfaces/libpq/test/libpq_uri-regress.c
@@ -1,5 +1,5 @@
 /*
- * uri-regress.c
+ * libpq_uri-regress.c
  *		A test program for libpq URI format
  *
  * This is a helper for libpq conninfo regression testing.  It takes a single
@@ -10,7 +10,7 @@
  * Portions Copyright (c) 2012-2022, PostgreSQL Global Development Group
  *
  * IDENTIFICATION
- *		src/interfaces/libpq/test/uri-regress.c
+ *		src/interfaces/libpq/test/libpq_uri-regress.c
  */
 
 #include "postgres_fe.h"
@@ -33,14 +33,14 @@ main(int argc, char *argv[])
 	opts = PQconninfoParse(argv[1], &errmsg);
 	if (opts == NULL)
 	{
-		fprintf(stderr, "uri-regress: %s", errmsg);
+		fprintf(stderr, "libpq_uri-regress: %s", errmsg);
 		return 1;
 	}
 
 	defs = PQconndefaults();
 	if (defs == NULL)
 	{
-		fprintf(stderr, "uri-regress: cannot fetch default options\n");
+		fprintf(stderr, "libpq_uri-regress: cannot fetch default options\n");
 		return 1;
 	}
 
diff --git a/src/tools/msvc/Mkvcbuild.pm b/src/tools/msvc/Mkvcbuild.pm
index fc04e1db8e..76b7ee6b95 100644
--- a/src/tools/msvc/Mkvcbuild.pm
+++ b/src/tools/msvc/Mkvcbuild.pm
@@ -285,17 +285,17 @@ sub mkvcbuild
 	$libpqwalreceiver->AddReference($postgres, $libpq);
 
 	my $libpq_testclient =
-	  $solution->AddProject('testclient', 'exe', 'misc',
+	  $solution->AddProject('libpq_testclient', 'exe', 'misc',
 							'src/interfaces/libpq/test');
-	$libpq_testclient->AddFile('src/interfaces/libpq/test/testclient.c');
+	$libpq_testclient->AddFile('src/interfaces/libpq/test/libpq_testclient.c');
 	$libpq_testclient->AddIncludeDir('src/interfaces/libpq');
 	$libpq_testclient->AddReference($libpgport, $libpq);
 	$libpq_testclient->AddLibrary('ws2_32.lib');
 
 	my $libpq_uri_regress =
-	  $solution->AddProject('uri-regress', 'exe', 'misc',
+	  $solution->AddProject('libpq_uri-regress', 'exe', 'misc',
 							'src/interfaces/libpq/test');
-	$libpq_uri_regress->AddFile('src/interfaces/libpq/test/uri-regress.c');
+	$libpq_uri_regress->AddFile('src/interfaces/libpq/test/libpq_uri-regress.c');
 	$libpq_uri_regress->AddIncludeDir('src/interfaces/libpq');
 	$libpq_uri_regress->AddReference($libpgport, $libpq);
 	$libpq_uri_regress->AddLibrary('ws2_32.lib');
-- 
2.32.0 (Apple Git-132)

